Skip to contents

[Deprecated]

A wrapper around shinyGovstyle::external_link(), preserving the function here in dfeshiny for backwards compatibility in upcoming versions only.

All logic and documentation is now in shinyGovstyle::external_link(), so please refer to that function for more information, and update your code to use that function directly.

Usage

external_link(...)

Arguments

...

Arguments passed to shinyGovstyle::external_link().

Value

The result of shinyGovstyle::external_link(...).