Skip to contents

[Deprecated]

A wrapper around shinyGovstyle::govReactable(), preserving the function here in dfeshiny for backwards compatibility in upcoming versions only.

All logic and documentation is now in shinyGovstyle::govReactable(), so please refer to that function for more information, and update your code to use that function directly.

Usage

dfe_reactable(data, ...)

Arguments

data

A data frame to display in the table.

...

Arguments passed to shinyGovstyle::govReactable().

Value

The result of shinyGovstyle::govReactable(...).