External link
external_link.RdA wrapper around shinyGovstyle::external_link(), preserving the function
here in dfeshiny for backwards compatibility in upcoming versions only.
All logic and documentation is now in shinyGovstyle::external_link(), so
please refer to that function for more information, and update your code
to use that function directly.
Arguments
- ...
Arguments passed to
shinyGovstyle::external_link().